# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_clientserver_ufs.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_clientserver_ufs.proto',
  package='',
  syntax='proto2',
  serialized_options=b'H\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$steammessages_clientserver_ufs.proto\x1a\x18steammessages_base.proto\"\x86\x02\n\x1e\x43MsgClientUFSUploadFileRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_size\x18\x02 \x01(\r\x12\x15\n\rraw_file_size\x18\x03 \x01(\r\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x11\n\tfile_name\x18\x06 \x01(\t\x12$\n\x1cplatforms_to_sync_deprecated\x18\x07 \x01(\r\x12%\n\x11platforms_to_sync\x18\x08 \x01(\r:\n4294967295\x12\x0f\n\x07\x63\x65ll_id\x18\t \x01(\r\x12\x13\n\x0b\x63\x61n_encrypt\x18\n \x01(\x08\"\xbb\x01\n\x1f\x43MsgClientUFSUploadFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x08sha_file\x18\x02 \x01(\x0c\x12\x10\n\x08use_http\x18\x03 \x01(\x08\x12\x11\n\thttp_host\x18\x04 \x01(\t\x12\x10\n\x08http_url\x18\x05 \x01(\t\x12\x12\n\nkv_headers\x18\x06 \x01(\x0c\x12\x11\n\tuse_https\x18\x07 \x01(\x08\x12\x14\n\x0c\x65ncrypt_file\x18\x08 \x01(\x08\"\xae\x01\n\x19\x43MsgClientUFSUploadCommit\x12.\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.CMsgClientUFSUploadCommit.File\x1a\x61\n\x04\x46ile\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08sha_file\x18\x03 \x01(\x0c\x12\x10\n\x08\x63ub_file\x18\x04 \x01(\r\x12\x11\n\tfile_name\x18\x05 \x01(\t\"\x99\x01\n!CMsgClientUFSUploadCommitResponse\x12\x36\n\x05\x66iles\x18\x01 \x03(\x0b\x32\'.CMsgClientUFSUploadCommitResponse.File\x1a<\n\x04\x46ile\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x10\n\x08sha_file\x18\x03 \x01(\x0c\"L\n\x16\x43MsgClientUFSFileChunk\x12\x10\n\x08sha_file\x18\x01 \x01(\x0c\x12\x12\n\nfile_start\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\" \n\x1e\x43MsgClientUFSTransferHeartbeat\"G\n\x1f\x43MsgClientUFSUploadFileFinished\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x10\n\x08sha_file\x18\x02 \x01(\x0c\"_\n\x1e\x43MsgClientUFSDeleteFileRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x1a\n\x12is_explicit_delete\x18\x03 \x01(\x08\"H\n\x1f\x43MsgClientUFSDeleteFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x11\n\tfile_name\x18\x02 \x01(\t\"S\n\x1e\x43MsgClientUFSGetFileListForApp\x12\x15\n\rapps_to_query\x18\x01 \x03(\r\x12\x1a\n\x12send_path_prefixes\x18\x02 \x01(\x08\"\xc1\x02\n&CMsgClientUFSGetFileListForAppResponse\x12;\n\x05\x66iles\x18\x01 \x03(\x0b\x32,.CMsgClientUFSGetFileListForAppResponse.File\x12\x15\n\rpath_prefixes\x18\x02 \x03(\t\x1a\xb8\x01\n\x04\x46ile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x10\n\x08sha_file\x18\x03 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x04 \x01(\x04\x12\x15\n\rraw_file_size\x18\x05 \x01(\r\x12\x1a\n\x12is_explicit_delete\x18\x06 \x01(\x08\x12\x19\n\x11platforms_to_sync\x18\x07 \x01(\r\x12\x19\n\x11path_prefix_index\x18\x08 \x01(\r:\x08\x80\xb5\x18\x08\x88\xb5\x18\x10\"Z\n\x1c\x43MsgClientUFSDownloadRequest\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\x12\x17\n\x0f\x63\x61n_handle_http\x18\x03 \x01(\x08\"\xa0\x02\n\x1d\x43MsgClientUFSDownloadResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x11\n\tfile_size\x18\x03 \x01(\r\x12\x15\n\rraw_file_size\x18\x04 \x01(\r\x12\x10\n\x08sha_file\x18\x05 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x06 \x01(\x04\x12\x1a\n\x12is_explicit_delete\x18\x07 \x01(\x08\x12\x10\n\x08use_http\x18\x08 \x01(\x08\x12\x11\n\thttp_host\x18\t \x01(\t\x12\x10\n\x08http_url\x18\n \x01(\t\x12\x12\n\nkv_headers\x18\x0b \x01(\x0c\x12\x11\n\tuse_https\x18\x0c \x01(\x08\x12\x11\n\tencrypted\x18\r \x01(\x08\"]\n\x19\x43MsgClientUFSLoginRequest\x12\x18\n\x10protocol_version\x18\x01 \x01(\r\x12\x18\n\x10\x61m_session_token\x18\x02 \x01(\x04\x12\x0c\n\x04\x61pps\x18\x03 \x03(\r\"0\n\x1a\x43MsgClientUFSLoginResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\"D\n\x1a\x43MsgClientUFSGetUGCDetails\x12&\n\x08hcontent\x18\x01 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\"\xe5\x01\n\"CMsgClientUFSGetUGCDetailsResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\r\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x17\n\x0fsteamid_creator\x18\x05 \x01(\x06\x12\x11\n\tfile_size\x18\x06 \x01(\r\x12\x1c\n\x14\x63ompressed_file_size\x18\x07 \x01(\r\x12\x17\n\x0frangecheck_host\x18\x08 \x01(\t\x12\x19\n\x11\x66ile_encoded_sha1\x18\t \x01(\t\"C\n\x1e\x43MsgClientUFSGetSingleFileInfo\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\xb8\x01\n&CMsgClientUFSGetSingleFileInfoResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\r\x12\x11\n\tfile_name\x18\x03 \x01(\t\x12\x10\n\x08sha_file\x18\x04 \x01(\x0c\x12\x12\n\ntime_stamp\x18\x05 \x01(\x04\x12\x15\n\rraw_file_size\x18\x06 \x01(\r\x12\x1a\n\x12is_explicit_delete\x18\x07 \x01(\x08\";\n\x16\x43MsgClientUFSShareFile\x12\x0e\n\x06\x61pp_id\x18\x01 \x01(\r\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\\\n\x1e\x43MsgClientUFSShareFileResponse\x12\x12\n\x07\x65result\x18\x01 \x01(\x05:\x01\x32\x12&\n\x08hcontent\x18\x02 \x01(\x06:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x42\x05H\x01\x90\x01\x00'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,])




_CMSGCLIENTUFSUPLOADFILEREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSUploadFileRequest',
  full_name='CMsgClientUFSUploadFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSUploadFileRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUFSUploadFileRequest.file_size', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSUploadFileRequest.raw_file_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadFileRequest.sha_file', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSUploadFileRequest.time_stamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSUploadFileRequest.file_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platforms_to_sync_deprecated', full_name='CMsgClientUFSUploadFileRequest.platforms_to_sync_deprecated', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platforms_to_sync', full_name='CMsgClientUFSUploadFileRequest.platforms_to_sync', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=4294967295,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cell_id', full_name='CMsgClientUFSUploadFileRequest.cell_id', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_encrypt', full_name='CMsgClientUFSUploadFileRequest.can_encrypt', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=329,
)


_CMSGCLIENTUFSUPLOADFILERESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSUploadFileResponse',
  full_name='CMsgClientUFSUploadFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadFileResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadFileResponse.sha_file', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_http', full_name='CMsgClientUFSUploadFileResponse.use_http', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_host', full_name='CMsgClientUFSUploadFileResponse.http_host', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_url', full_name='CMsgClientUFSUploadFileResponse.http_url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kv_headers', full_name='CMsgClientUFSUploadFileResponse.kv_headers', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_https', full_name='CMsgClientUFSUploadFileResponse.use_https', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encrypt_file', full_name='CMsgClientUFSUploadFileResponse.encrypt_file', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=332,
  serialized_end=519,
)


_CMSGCLIENTUFSUPLOADCOMMIT_FILE = _descriptor.Descriptor(
  name='File',
  full_name='CMsgClientUFSUploadCommit.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadCommit.File.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSUploadCommit.File.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadCommit.File.sha_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cub_file', full_name='CMsgClientUFSUploadCommit.File.cub_file', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSUploadCommit.File.file_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=696,
)

_CMSGCLIENTUFSUPLOADCOMMIT = _descriptor.Descriptor(
  name='CMsgClientUFSUploadCommit',
  full_name='CMsgClientUFSUploadCommit',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CMsgClientUFSUploadCommit.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUFSUPLOADCOMMIT_FILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=522,
  serialized_end=696,
)


_CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE = _descriptor.Descriptor(
  name='File',
  full_name='CMsgClientUFSUploadCommitResponse.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadCommitResponse.File.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSUploadCommitResponse.File.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadCommitResponse.File.sha_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=659,
)

_CMSGCLIENTUFSUPLOADCOMMITRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSUploadCommitResponse',
  full_name='CMsgClientUFSUploadCommitResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CMsgClientUFSUploadCommitResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=699,
  serialized_end=852,
)


_CMSGCLIENTUFSFILECHUNK = _descriptor.Descriptor(
  name='CMsgClientUFSFileChunk',
  full_name='CMsgClientUFSFileChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSFileChunk.sha_file', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_start', full_name='CMsgClientUFSFileChunk.file_start', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='CMsgClientUFSFileChunk.data', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=854,
  serialized_end=930,
)


_CMSGCLIENTUFSTRANSFERHEARTBEAT = _descriptor.Descriptor(
  name='CMsgClientUFSTransferHeartbeat',
  full_name='CMsgClientUFSTransferHeartbeat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=932,
  serialized_end=964,
)


_CMSGCLIENTUFSUPLOADFILEFINISHED = _descriptor.Descriptor(
  name='CMsgClientUFSUploadFileFinished',
  full_name='CMsgClientUFSUploadFileFinished',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSUploadFileFinished.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSUploadFileFinished.sha_file', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=966,
  serialized_end=1037,
)


_CMSGCLIENTUFSDELETEFILEREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSDeleteFileRequest',
  full_name='CMsgClientUFSDeleteFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSDeleteFileRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSDeleteFileRequest.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSDeleteFileRequest.is_explicit_delete', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1039,
  serialized_end=1134,
)


_CMSGCLIENTUFSDELETEFILERESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSDeleteFileResponse',
  full_name='CMsgClientUFSDeleteFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSDeleteFileResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSDeleteFileResponse.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1136,
  serialized_end=1208,
)


_CMSGCLIENTUFSGETFILELISTFORAPP = _descriptor.Descriptor(
  name='CMsgClientUFSGetFileListForApp',
  full_name='CMsgClientUFSGetFileListForApp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='apps_to_query', full_name='CMsgClientUFSGetFileListForApp.apps_to_query', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send_path_prefixes', full_name='CMsgClientUFSGetFileListForApp.send_path_prefixes', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1210,
  serialized_end=1293,
)


_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE = _descriptor.Descriptor(
  name='File',
  full_name='CMsgClientUFSGetFileListForAppResponse.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetFileListForAppResponse.File.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSGetFileListForAppResponse.File.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSGetFileListForAppResponse.File.sha_file', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSGetFileListForAppResponse.File.time_stamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSGetFileListForAppResponse.File.raw_file_size', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSGetFileListForAppResponse.File.is_explicit_delete', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platforms_to_sync', full_name='CMsgClientUFSGetFileListForAppResponse.File.platforms_to_sync', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_prefix_index', full_name='CMsgClientUFSGetFileListForAppResponse.File.path_prefix_index', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1423,
  serialized_end=1607,
)

_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSGetFileListForAppResponse',
  full_name='CMsgClientUFSGetFileListForAppResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='CMsgClientUFSGetFileListForAppResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_prefixes', full_name='CMsgClientUFSGetFileListForAppResponse.path_prefixes', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE, ],
  enum_types=[
  ],
  serialized_options=b'\200\265\030\010\210\265\030\020',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1296,
  serialized_end=1617,
)


_CMSGCLIENTUFSDOWNLOADREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSDownloadRequest',
  full_name='CMsgClientUFSDownloadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSDownloadRequest.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSDownloadRequest.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_handle_http', full_name='CMsgClientUFSDownloadRequest.can_handle_http', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1619,
  serialized_end=1709,
)


_CMSGCLIENTUFSDOWNLOADRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSDownloadResponse',
  full_name='CMsgClientUFSDownloadResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSDownloadResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSDownloadResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUFSDownloadResponse.file_size', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSDownloadResponse.raw_file_size', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSDownloadResponse.sha_file', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSDownloadResponse.time_stamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSDownloadResponse.is_explicit_delete', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_http', full_name='CMsgClientUFSDownloadResponse.use_http', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_host', full_name='CMsgClientUFSDownloadResponse.http_host', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_url', full_name='CMsgClientUFSDownloadResponse.http_url', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kv_headers', full_name='CMsgClientUFSDownloadResponse.kv_headers', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_https', full_name='CMsgClientUFSDownloadResponse.use_https', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='encrypted', full_name='CMsgClientUFSDownloadResponse.encrypted', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1712,
  serialized_end=2000,
)


_CMSGCLIENTUFSLOGINREQUEST = _descriptor.Descriptor(
  name='CMsgClientUFSLoginRequest',
  full_name='CMsgClientUFSLoginRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol_version', full_name='CMsgClientUFSLoginRequest.protocol_version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='am_session_token', full_name='CMsgClientUFSLoginRequest.am_session_token', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='apps', full_name='CMsgClientUFSLoginRequest.apps', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2002,
  serialized_end=2095,
)


_CMSGCLIENTUFSLOGINRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSLoginResponse',
  full_name='CMsgClientUFSLoginResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSLoginResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2097,
  serialized_end=2145,
)


_CMSGCLIENTUFSGETUGCDETAILS = _descriptor.Descriptor(
  name='CMsgClientUFSGetUGCDetails',
  full_name='CMsgClientUFSGetUGCDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hcontent', full_name='CMsgClientUFSGetUGCDetails.hcontent', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2147,
  serialized_end=2215,
)


_CMSGCLIENTUFSGETUGCDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSGetUGCDetailsResponse',
  full_name='CMsgClientUFSGetUGCDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSGetUGCDetailsResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='CMsgClientUFSGetUGCDetailsResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetUGCDetailsResponse.app_id', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filename', full_name='CMsgClientUFSGetUGCDetailsResponse.filename', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid_creator', full_name='CMsgClientUFSGetUGCDetailsResponse.steamid_creator', index=4,
      number=5, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='CMsgClientUFSGetUGCDetailsResponse.file_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compressed_file_size', full_name='CMsgClientUFSGetUGCDetailsResponse.compressed_file_size', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rangecheck_host', full_name='CMsgClientUFSGetUGCDetailsResponse.rangecheck_host', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_encoded_sha1', full_name='CMsgClientUFSGetUGCDetailsResponse.file_encoded_sha1', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2218,
  serialized_end=2447,
)


_CMSGCLIENTUFSGETSINGLEFILEINFO = _descriptor.Descriptor(
  name='CMsgClientUFSGetSingleFileInfo',
  full_name='CMsgClientUFSGetSingleFileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetSingleFileInfo.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSGetSingleFileInfo.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2449,
  serialized_end=2516,
)


_CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSGetSingleFileInfoResponse',
  full_name='CMsgClientUFSGetSingleFileInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSGetSingleFileInfoResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSGetSingleFileInfoResponse.app_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSGetSingleFileInfoResponse.file_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sha_file', full_name='CMsgClientUFSGetSingleFileInfoResponse.sha_file', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_stamp', full_name='CMsgClientUFSGetSingleFileInfoResponse.time_stamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_file_size', full_name='CMsgClientUFSGetSingleFileInfoResponse.raw_file_size', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_explicit_delete', full_name='CMsgClientUFSGetSingleFileInfoResponse.is_explicit_delete', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2519,
  serialized_end=2703,
)


_CMSGCLIENTUFSSHAREFILE = _descriptor.Descriptor(
  name='CMsgClientUFSShareFile',
  full_name='CMsgClientUFSShareFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='app_id', full_name='CMsgClientUFSShareFile.app_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='CMsgClientUFSShareFile.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2705,
  serialized_end=2764,
)


_CMSGCLIENTUFSSHAREFILERESPONSE = _descriptor.Descriptor(
  name='CMsgClientUFSShareFileResponse',
  full_name='CMsgClientUFSShareFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgClientUFSShareFileResponse.eresult', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hcontent', full_name='CMsgClientUFSShareFileResponse.hcontent', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=True, default_value=18446744073709551615,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2766,
  serialized_end=2858,
)

_CMSGCLIENTUFSUPLOADCOMMIT_FILE.containing_type = _CMSGCLIENTUFSUPLOADCOMMIT
_CMSGCLIENTUFSUPLOADCOMMIT.fields_by_name['files'].message_type = _CMSGCLIENTUFSUPLOADCOMMIT_FILE
_CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE.containing_type = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE
_CMSGCLIENTUFSUPLOADCOMMITRESPONSE.fields_by_name['files'].message_type = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE
_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE.containing_type = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE
_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE.fields_by_name['files'].message_type = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadFileRequest'] = _CMSGCLIENTUFSUPLOADFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadFileResponse'] = _CMSGCLIENTUFSUPLOADFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadCommit'] = _CMSGCLIENTUFSUPLOADCOMMIT
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadCommitResponse'] = _CMSGCLIENTUFSUPLOADCOMMITRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSFileChunk'] = _CMSGCLIENTUFSFILECHUNK
DESCRIPTOR.message_types_by_name['CMsgClientUFSTransferHeartbeat'] = _CMSGCLIENTUFSTRANSFERHEARTBEAT
DESCRIPTOR.message_types_by_name['CMsgClientUFSUploadFileFinished'] = _CMSGCLIENTUFSUPLOADFILEFINISHED
DESCRIPTOR.message_types_by_name['CMsgClientUFSDeleteFileRequest'] = _CMSGCLIENTUFSDELETEFILEREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSDeleteFileResponse'] = _CMSGCLIENTUFSDELETEFILERESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetFileListForApp'] = _CMSGCLIENTUFSGETFILELISTFORAPP
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetFileListForAppResponse'] = _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSDownloadRequest'] = _CMSGCLIENTUFSDOWNLOADREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSDownloadResponse'] = _CMSGCLIENTUFSDOWNLOADRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSLoginRequest'] = _CMSGCLIENTUFSLOGINREQUEST
DESCRIPTOR.message_types_by_name['CMsgClientUFSLoginResponse'] = _CMSGCLIENTUFSLOGINRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetUGCDetails'] = _CMSGCLIENTUFSGETUGCDETAILS
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetUGCDetailsResponse'] = _CMSGCLIENTUFSGETUGCDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetSingleFileInfo'] = _CMSGCLIENTUFSGETSINGLEFILEINFO
DESCRIPTOR.message_types_by_name['CMsgClientUFSGetSingleFileInfoResponse'] = _CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE
DESCRIPTOR.message_types_by_name['CMsgClientUFSShareFile'] = _CMSGCLIENTUFSSHAREFILE
DESCRIPTOR.message_types_by_name['CMsgClientUFSShareFileResponse'] = _CMSGCLIENTUFSSHAREFILERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CMsgClientUFSUploadFileRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADFILEREQUEST,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadFileRequest)
  })
_sym_db.RegisterMessage(CMsgClientUFSUploadFileRequest)

CMsgClientUFSUploadFileResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADFILERESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadFileResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSUploadFileResponse)

CMsgClientUFSUploadCommit = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadCommit', (_message.Message,), {

  'File' : _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADCOMMIT_FILE,
    '__module__' : 'steammessages_clientserver_ufs_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommit.File)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADCOMMIT,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommit)
  })
_sym_db.RegisterMessage(CMsgClientUFSUploadCommit)
_sym_db.RegisterMessage(CMsgClientUFSUploadCommit.File)

CMsgClientUFSUploadCommitResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadCommitResponse', (_message.Message,), {

  'File' : _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADCOMMITRESPONSE_FILE,
    '__module__' : 'steammessages_clientserver_ufs_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommitResponse.File)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADCOMMITRESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadCommitResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSUploadCommitResponse)
_sym_db.RegisterMessage(CMsgClientUFSUploadCommitResponse.File)

CMsgClientUFSFileChunk = _reflection.GeneratedProtocolMessageType('CMsgClientUFSFileChunk', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSFILECHUNK,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSFileChunk)
  })
_sym_db.RegisterMessage(CMsgClientUFSFileChunk)

CMsgClientUFSTransferHeartbeat = _reflection.GeneratedProtocolMessageType('CMsgClientUFSTransferHeartbeat', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSTRANSFERHEARTBEAT,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSTransferHeartbeat)
  })
_sym_db.RegisterMessage(CMsgClientUFSTransferHeartbeat)

CMsgClientUFSUploadFileFinished = _reflection.GeneratedProtocolMessageType('CMsgClientUFSUploadFileFinished', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSUPLOADFILEFINISHED,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSUploadFileFinished)
  })
_sym_db.RegisterMessage(CMsgClientUFSUploadFileFinished)

CMsgClientUFSDeleteFileRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDeleteFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSDELETEFILEREQUEST,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDeleteFileRequest)
  })
_sym_db.RegisterMessage(CMsgClientUFSDeleteFileRequest)

CMsgClientUFSDeleteFileResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDeleteFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSDELETEFILERESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDeleteFileResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSDeleteFileResponse)

CMsgClientUFSGetFileListForApp = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetFileListForApp', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSGETFILELISTFORAPP,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetFileListForApp)
  })
_sym_db.RegisterMessage(CMsgClientUFSGetFileListForApp)

CMsgClientUFSGetFileListForAppResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetFileListForAppResponse', (_message.Message,), {

  'File' : _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
    'DESCRIPTOR' : _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE_FILE,
    '__module__' : 'steammessages_clientserver_ufs_pb2'
    # @@protoc_insertion_point(class_scope:CMsgClientUFSGetFileListForAppResponse.File)
    })
  ,
  'DESCRIPTOR' : _CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetFileListForAppResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSGetFileListForAppResponse)
_sym_db.RegisterMessage(CMsgClientUFSGetFileListForAppResponse.File)

CMsgClientUFSDownloadRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDownloadRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSDOWNLOADREQUEST,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDownloadRequest)
  })
_sym_db.RegisterMessage(CMsgClientUFSDownloadRequest)

CMsgClientUFSDownloadResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSDownloadResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSDOWNLOADRESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSDownloadResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSDownloadResponse)

CMsgClientUFSLoginRequest = _reflection.GeneratedProtocolMessageType('CMsgClientUFSLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSLOGINREQUEST,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSLoginRequest)
  })
_sym_db.RegisterMessage(CMsgClientUFSLoginRequest)

CMsgClientUFSLoginResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSLOGINRESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSLoginResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSLoginResponse)

CMsgClientUFSGetUGCDetails = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetUGCDetails', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSGETUGCDETAILS,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetUGCDetails)
  })
_sym_db.RegisterMessage(CMsgClientUFSGetUGCDetails)

CMsgClientUFSGetUGCDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetUGCDetailsResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSGETUGCDETAILSRESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetUGCDetailsResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSGetUGCDetailsResponse)

CMsgClientUFSGetSingleFileInfo = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetSingleFileInfo', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSGETSINGLEFILEINFO,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetSingleFileInfo)
  })
_sym_db.RegisterMessage(CMsgClientUFSGetSingleFileInfo)

CMsgClientUFSGetSingleFileInfoResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSGetSingleFileInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSGETSINGLEFILEINFORESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSGetSingleFileInfoResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSGetSingleFileInfoResponse)

CMsgClientUFSShareFile = _reflection.GeneratedProtocolMessageType('CMsgClientUFSShareFile', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSSHAREFILE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSShareFile)
  })
_sym_db.RegisterMessage(CMsgClientUFSShareFile)

CMsgClientUFSShareFileResponse = _reflection.GeneratedProtocolMessageType('CMsgClientUFSShareFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CMSGCLIENTUFSSHAREFILERESPONSE,
  '__module__' : 'steammessages_clientserver_ufs_pb2'
  # @@protoc_insertion_point(class_scope:CMsgClientUFSShareFileResponse)
  })
_sym_db.RegisterMessage(CMsgClientUFSShareFileResponse)


DESCRIPTOR._options = None
_CMSGCLIENTUFSGETFILELISTFORAPPRESPONSE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_shader.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_shader.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1asteammessages_shader.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xc9\x01\n\x1e\x43Shader_RegisterShader_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\x12\x37\n\x07shaders\x18\x04 \x03(\x0b\x32&.CShader_RegisterShader_Request.Shader\x1a\x38\n\x06Shader\x12\x15\n\rcache_key_sha\x18\x01 \x01(\x0c\x12\x17\n\x0fshader_code_sha\x18\x02 \x01(\x0c\"<\n\x1f\x43Shader_RegisterShader_Response\x12\x19\n\x11requested_codeids\x18\x01 \x03(\r\"\xa0\x01\n\x1a\x43Shader_SendShader_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x37\n\x07shaders\x18\x02 \x03(\x0b\x32&.CShader_SendShader_Request.ShaderCode\x1a:\n\nShaderCode\x12\x17\n\x0fshader_code_sha\x18\x01 \x01(\x0c\x12\x13\n\x0bshader_code\x18\x02 \x01(\x0c\"\x1d\n\x1b\x43Shader_SendShader_Response\"Y\n!CShader_GetBucketManifest_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\"]\n\"CShader_GetBucketManifest_Response\x12\x12\n\nmanifestid\x18\x01 \x01(\x04\x12\x11\n\tdepotsize\x18\x02 \x01(\x04\x12\x10\n\x08\x62ucketid\x18\x03 \x01(\x04\"G\n\x1e\x43Shader_GetStaleBucket_Request\x12\x10\n\x08gpu_desc\x18\x01 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x02 \x01(\t\"\x9b\x01\n\x1f\x43Shader_GetStaleBucket_Response\x12\x10\n\x08\x62ucketid\x18\x01 \x01(\x04\x12\r\n\x05\x61ppid\x18\x02 \x01(\r\x12\x12\n\nmanifestid\x18\x03 \x01(\x04\x12\x10\n\x08gpu_desc\x18\x04 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x05 \x01(\t\x12\x1c\n\x14\x64\x65pot_encryption_key\x18\x06 \x01(\x0c\"\xb7\x01\n#CShader_ReportExternalBuild_Request\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x10\n\x08gpu_desc\x18\x02 \x01(\t\x12\x13\n\x0b\x64river_desc\x18\x03 \x01(\t\x12\x12\n\nmanifestid\x18\x04 \x01(\x04\x12\x17\n\x0fsource_gpu_desc\x18\x05 \x01(\t\x12\x1a\n\x12source_driver_desc\x18\x06 \x01(\t\x12\x11\n\tdepotsize\x18\x07 \x01(\x04\"&\n$CShader_ReportExternalBuild_Response2\xbb\x06\n\x06Shader\x12\xbe\x01\n\x0eRegisterShader\x12\x1f.CShader_RegisterShader_Request\x1a .CShader_RegisterShader_Response\"i\x82\xb5\x18\x65\x43lient just finished playing a game, detected new shader cache entries and is notifying us about them\x12\x8f\x01\n\nSendShader\x12\x1b.CShader_SendShader_Request\x1a\x1c.CShader_SendShader_Response\"F\x82\xb5\x18\x42\x43lient is sending us actual compiled shader code that we requested\x12\xad\x01\n\x11GetBucketManifest\x12\".CShader_GetBucketManifest_Request\x1a#.CShader_GetBucketManifest_Response\"O\x82\xb5\x18KClient wants to know the manifest ID to fetch (if any) for a bucket\'s depot\x12\x8e\x01\n\x0eGetStaleBucket\x12\x1f.CShader_GetStaleBucket_Request\x1a .CShader_GetStaleBucket_Response\"9\x82\xb5\x18\x35Job to get a stale bucket given a gpu and driver desc\x12\x88\x01\n\x13ReportExternalBuild\x12$.CShader_ReportExternalBuild_Request\x1a%.CShader_ReportExternalBuild_Response\"$\x82\xb5\x18 Report an exernally built bucket\x1a\x12\x82\xb5\x18\x0eShader methodsB\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])




_CSHADER_REGISTERSHADER_REQUEST_SHADER = _descriptor.Descriptor(
  name='Shader',
  full_name='CShader_RegisterShader_Request.Shader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_key_sha', full_name='CShader_RegisterShader_Request.Shader.cache_key_sha', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shader_code_sha', full_name='CShader_RegisterShader_Request.Shader.shader_code_sha', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=292,
)

_CSHADER_REGISTERSHADER_REQUEST = _descriptor.Descriptor(
  name='CShader_RegisterShader_Request',
  full_name='CShader_RegisterShader_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CShader_RegisterShader_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_desc', full_name='CShader_RegisterShader_Request.gpu_desc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_desc', full_name='CShader_RegisterShader_Request.driver_desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shaders', full_name='CShader_RegisterShader_Request.shaders', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSHADER_REGISTERSHADER_REQUEST_SHADER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=91,
  serialized_end=292,
)


_CSHADER_REGISTERSHADER_RESPONSE = _descriptor.Descriptor(
  name='CShader_RegisterShader_Response',
  full_name='CShader_RegisterShader_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='requested_codeids', full_name='CShader_RegisterShader_Response.requested_codeids', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=294,
  serialized_end=354,
)


_CSHADER_SENDSHADER_REQUEST_SHADERCODE = _descriptor.Descriptor(
  name='ShaderCode',
  full_name='CShader_SendShader_Request.ShaderCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shader_code_sha', full_name='CShader_SendShader_Request.ShaderCode.shader_code_sha', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shader_code', full_name='CShader_SendShader_Request.ShaderCode.shader_code', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=517,
)

_CSHADER_SENDSHADER_REQUEST = _descriptor.Descriptor(
  name='CShader_SendShader_Request',
  full_name='CShader_SendShader_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CShader_SendShader_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='shaders', full_name='CShader_SendShader_Request.shaders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CSHADER_SENDSHADER_REQUEST_SHADERCODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=517,
)


_CSHADER_SENDSHADER_RESPONSE = _descriptor.Descriptor(
  name='CShader_SendShader_Response',
  full_name='CShader_SendShader_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=548,
)


_CSHADER_GETBUCKETMANIFEST_REQUEST = _descriptor.Descriptor(
  name='CShader_GetBucketManifest_Request',
  full_name='CShader_GetBucketManifest_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CShader_GetBucketManifest_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_desc', full_name='CShader_GetBucketManifest_Request.gpu_desc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_desc', full_name='CShader_GetBucketManifest_Request.driver_desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=639,
)


_CSHADER_GETBUCKETMANIFEST_RESPONSE = _descriptor.Descriptor(
  name='CShader_GetBucketManifest_Response',
  full_name='CShader_GetBucketManifest_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='manifestid', full_name='CShader_GetBucketManifest_Response.manifestid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depotsize', full_name='CShader_GetBucketManifest_Response.depotsize', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucketid', full_name='CShader_GetBucketManifest_Response.bucketid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=734,
)


_CSHADER_GETSTALEBUCKET_REQUEST = _descriptor.Descriptor(
  name='CShader_GetStaleBucket_Request',
  full_name='CShader_GetStaleBucket_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gpu_desc', full_name='CShader_GetStaleBucket_Request.gpu_desc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_desc', full_name='CShader_GetStaleBucket_Request.driver_desc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=807,
)


_CSHADER_GETSTALEBUCKET_RESPONSE = _descriptor.Descriptor(
  name='CShader_GetStaleBucket_Response',
  full_name='CShader_GetStaleBucket_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucketid', full_name='CShader_GetStaleBucket_Response.bucketid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='appid', full_name='CShader_GetStaleBucket_Response.appid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifestid', full_name='CShader_GetStaleBucket_Response.manifestid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_desc', full_name='CShader_GetStaleBucket_Response.gpu_desc', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_desc', full_name='CShader_GetStaleBucket_Response.driver_desc', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depot_encryption_key', full_name='CShader_GetStaleBucket_Response.depot_encryption_key', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=965,
)


_CSHADER_REPORTEXTERNALBUILD_REQUEST = _descriptor.Descriptor(
  name='CShader_ReportExternalBuild_Request',
  full_name='CShader_ReportExternalBuild_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='appid', full_name='CShader_ReportExternalBuild_Request.appid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_desc', full_name='CShader_ReportExternalBuild_Request.gpu_desc', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver_desc', full_name='CShader_ReportExternalBuild_Request.driver_desc', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='manifestid', full_name='CShader_ReportExternalBuild_Request.manifestid', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_gpu_desc', full_name='CShader_ReportExternalBuild_Request.source_gpu_desc', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_driver_desc', full_name='CShader_ReportExternalBuild_Request.source_driver_desc', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depotsize', full_name='CShader_ReportExternalBuild_Request.depotsize', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=968,
  serialized_end=1151,
)


_CSHADER_REPORTEXTERNALBUILD_RESPONSE = _descriptor.Descriptor(
  name='CShader_ReportExternalBuild_Response',
  full_name='CShader_ReportExternalBuild_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1153,
  serialized_end=1191,
)

_CSHADER_REGISTERSHADER_REQUEST_SHADER.containing_type = _CSHADER_REGISTERSHADER_REQUEST
_CSHADER_REGISTERSHADER_REQUEST.fields_by_name['shaders'].message_type = _CSHADER_REGISTERSHADER_REQUEST_SHADER
_CSHADER_SENDSHADER_REQUEST_SHADERCODE.containing_type = _CSHADER_SENDSHADER_REQUEST
_CSHADER_SENDSHADER_REQUEST.fields_by_name['shaders'].message_type = _CSHADER_SENDSHADER_REQUEST_SHADERCODE
DESCRIPTOR.message_types_by_name['CShader_RegisterShader_Request'] = _CSHADER_REGISTERSHADER_REQUEST
DESCRIPTOR.message_types_by_name['CShader_RegisterShader_Response'] = _CSHADER_REGISTERSHADER_RESPONSE
DESCRIPTOR.message_types_by_name['CShader_SendShader_Request'] = _CSHADER_SENDSHADER_REQUEST
DESCRIPTOR.message_types_by_name['CShader_SendShader_Response'] = _CSHADER_SENDSHADER_RESPONSE
DESCRIPTOR.message_types_by_name['CShader_GetBucketManifest_Request'] = _CSHADER_GETBUCKETMANIFEST_REQUEST
DESCRIPTOR.message_types_by_name['CShader_GetBucketManifest_Response'] = _CSHADER_GETBUCKETMANIFEST_RESPONSE
DESCRIPTOR.message_types_by_name['CShader_GetStaleBucket_Request'] = _CSHADER_GETSTALEBUCKET_REQUEST
DESCRIPTOR.message_types_by_name['CShader_GetStaleBucket_Response'] = _CSHADER_GETSTALEBUCKET_RESPONSE
DESCRIPTOR.message_types_by_name['CShader_ReportExternalBuild_Request'] = _CSHADER_REPORTEXTERNALBUILD_REQUEST
DESCRIPTOR.message_types_by_name['CShader_ReportExternalBuild_Response'] = _CSHADER_REPORTEXTERNALBUILD_RESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CShader_RegisterShader_Request = _reflection.GeneratedProtocolMessageType('CShader_RegisterShader_Request', (_message.Message,), {

  'Shader' : _reflection.GeneratedProtocolMessageType('Shader', (_message.Message,), {
    'DESCRIPTOR' : _CSHADER_REGISTERSHADER_REQUEST_SHADER,
    '__module__' : 'steammessages_shader_pb2'
    # @@protoc_insertion_point(class_scope:CShader_RegisterShader_Request.Shader)
    })
  ,
  'DESCRIPTOR' : _CSHADER_REGISTERSHADER_REQUEST,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_RegisterShader_Request)
  })
_sym_db.RegisterMessage(CShader_RegisterShader_Request)
_sym_db.RegisterMessage(CShader_RegisterShader_Request.Shader)

CShader_RegisterShader_Response = _reflection.GeneratedProtocolMessageType('CShader_RegisterShader_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_REGISTERSHADER_RESPONSE,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_RegisterShader_Response)
  })
_sym_db.RegisterMessage(CShader_RegisterShader_Response)

CShader_SendShader_Request = _reflection.GeneratedProtocolMessageType('CShader_SendShader_Request', (_message.Message,), {

  'ShaderCode' : _reflection.GeneratedProtocolMessageType('ShaderCode', (_message.Message,), {
    'DESCRIPTOR' : _CSHADER_SENDSHADER_REQUEST_SHADERCODE,
    '__module__' : 'steammessages_shader_pb2'
    # @@protoc_insertion_point(class_scope:CShader_SendShader_Request.ShaderCode)
    })
  ,
  'DESCRIPTOR' : _CSHADER_SENDSHADER_REQUEST,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_SendShader_Request)
  })
_sym_db.RegisterMessage(CShader_SendShader_Request)
_sym_db.RegisterMessage(CShader_SendShader_Request.ShaderCode)

CShader_SendShader_Response = _reflection.GeneratedProtocolMessageType('CShader_SendShader_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_SENDSHADER_RESPONSE,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_SendShader_Response)
  })
_sym_db.RegisterMessage(CShader_SendShader_Response)

CShader_GetBucketManifest_Request = _reflection.GeneratedProtocolMessageType('CShader_GetBucketManifest_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_GETBUCKETMANIFEST_REQUEST,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_GetBucketManifest_Request)
  })
_sym_db.RegisterMessage(CShader_GetBucketManifest_Request)

CShader_GetBucketManifest_Response = _reflection.GeneratedProtocolMessageType('CShader_GetBucketManifest_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_GETBUCKETMANIFEST_RESPONSE,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_GetBucketManifest_Response)
  })
_sym_db.RegisterMessage(CShader_GetBucketManifest_Response)

CShader_GetStaleBucket_Request = _reflection.GeneratedProtocolMessageType('CShader_GetStaleBucket_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_GETSTALEBUCKET_REQUEST,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_GetStaleBucket_Request)
  })
_sym_db.RegisterMessage(CShader_GetStaleBucket_Request)

CShader_GetStaleBucket_Response = _reflection.GeneratedProtocolMessageType('CShader_GetStaleBucket_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_GETSTALEBUCKET_RESPONSE,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_GetStaleBucket_Response)
  })
_sym_db.RegisterMessage(CShader_GetStaleBucket_Response)

CShader_ReportExternalBuild_Request = _reflection.GeneratedProtocolMessageType('CShader_ReportExternalBuild_Request', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_REPORTEXTERNALBUILD_REQUEST,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_ReportExternalBuild_Request)
  })
_sym_db.RegisterMessage(CShader_ReportExternalBuild_Request)

CShader_ReportExternalBuild_Response = _reflection.GeneratedProtocolMessageType('CShader_ReportExternalBuild_Response', (_message.Message,), {
  'DESCRIPTOR' : _CSHADER_REPORTEXTERNALBUILD_RESPONSE,
  '__module__' : 'steammessages_shader_pb2'
  # @@protoc_insertion_point(class_scope:CShader_ReportExternalBuild_Response)
  })
_sym_db.RegisterMessage(CShader_ReportExternalBuild_Response)


DESCRIPTOR._options = None

_SHADER = _descriptor.ServiceDescriptor(
  name='Shader',
  full_name='Shader',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030\016Shader methods',
  create_key=_descriptor._internal_create_key,
  serialized_start=1194,
  serialized_end=2021,
  methods=[
  _descriptor.MethodDescriptor(
    name='RegisterShader',
    full_name='Shader.RegisterShader',
    index=0,
    containing_service=None,
    input_type=_CSHADER_REGISTERSHADER_REQUEST,
    output_type=_CSHADER_REGISTERSHADER_RESPONSE,
    serialized_options=b'\202\265\030eClient just finished playing a game, detected new shader cache entries and is notifying us about them',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendShader',
    full_name='Shader.SendShader',
    index=1,
    containing_service=None,
    input_type=_CSHADER_SENDSHADER_REQUEST,
    output_type=_CSHADER_SENDSHADER_RESPONSE,
    serialized_options=b'\202\265\030BClient is sending us actual compiled shader code that we requested',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetBucketManifest',
    full_name='Shader.GetBucketManifest',
    index=2,
    containing_service=None,
    input_type=_CSHADER_GETBUCKETMANIFEST_REQUEST,
    output_type=_CSHADER_GETBUCKETMANIFEST_RESPONSE,
    serialized_options=b'\202\265\030KClient wants to know the manifest ID to fetch (if any) for a bucket\'s depot',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStaleBucket',
    full_name='Shader.GetStaleBucket',
    index=3,
    containing_service=None,
    input_type=_CSHADER_GETSTALEBUCKET_REQUEST,
    output_type=_CSHADER_GETSTALEBUCKET_RESPONSE,
    serialized_options=b'\202\265\0305Job to get a stale bucket given a gpu and driver desc',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ReportExternalBuild',
    full_name='Shader.ReportExternalBuild',
    index=4,
    containing_service=None,
    input_type=_CSHADER_REPORTEXTERNALBUILD_REQUEST,
    output_type=_CSHADER_REPORTEXTERNALBUILD_RESPONSE,
    serialized_options=b'\202\265\030 Report an exernally built bucket',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SHADER)

DESCRIPTOR.services_by_name['Shader'] = _SHADER

Shader = service_reflection.GeneratedServiceType('Shader', (_service.Service,), dict(
  DESCRIPTOR = _SHADER,
  __module__ = 'steammessages_shader_pb2'
  ))

Shader_Stub = service_reflection.GeneratedServiceStubType('Shader_Stub', (Shader,), dict(
  DESCRIPTOR = _SHADER,
  __module__ = 'steammessages_shader_pb2'
  ))


# @@protoc_insertion_point(module_scope)
